==> qore-1.10.0.tar.bz2: qore-1.10.0/docs/modules/SalesforceRestDataProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SalesforceRestDataProvider Module Reference", "index.html", [
    [ "SalesforceRestDataProvider Module", "index.html", [
      [ "Introduction to the SalesforceRestDataProvider Module", "index.html#salesforcerestdataproviderintro", null ],
      [ "Salesforce Queries", "index.html#salesforcerestdataprovider_queries", null ],
      [ "Release Notes", "index.html#salesforcerestdataprovider_relnotes", [
        [ "SalesforceRestDataProvider v1.0.1", "index.html#salesforcerestdataprovider_v1_0_1", null ],
        [ "SalesforceRestDataProvider v1.0", "index.html#salesforcerestdataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#ga83e582adb5ad1401911345ba306dabd2",
"group__file__locking__constants.html#ga6df55e6d2cd8d49cb714afe15f4d6b63",
"group__misc__functions.html#ga11da5fd06dcfa57a48a5381268a52086",
"group__parse__options.html#ga889aa80f8ab33266c165478b5fe3c279",
"group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b",
"namespace_salesforce_rest_data_provider.html#a525b6ddaff084253b106b1d1833c9284"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.12.3.tar.bz2: qore-1.12.3/docs/modules/SalesforceRestDataProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SalesforceRestDataProvider Module Reference", "index.html", [
    [ "SalesforceRestDataProvider Module", "index.html", [
      [ "Introduction to the SalesforceRestDataProvider Module", "index.html#salesforcerestdataproviderintro", null ],
      [ "Salesforce Queries", "index.html#salesforcerestdataprovider_queries", null ],
      [ "Release Notes", "index.html#salesforcerestdataprovider_relnotes", [
        [ "SalesforceRestDataProvider v1.0.1", "index.html#salesforcerestdataprovider_v1_0_1", null ],
        [ "SalesforceRestDataProvider v1.0", "index.html#salesforcerestdataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#ga014569059b153ad30b0951ba0113bd04",
"group__error__constants.html#gae7bad5e705a0451e8d0718203abe3d2e",
"group__math__functions.html#ga764e8653af1f7486a5094e4f82076144",
"group__option__constants.html#gae9654317eddd561ad25dbdf76959a60e",
"group__string__functions.html#gab998e345a65c1e98ca9370c3a324f9cb",
"group__x509__verification__constants.html#ga757330b3e07026d87148774bd15eefa4"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
